require "rails_helper"

RSpec.describe Form::Sales::Pages::PrivacyNotice, type: :model do
  subject(:page) { described_class.new(page_id, page_definition, subsection, joint_purchase: false) }

  let(:page_id) { "privacy_notice" }
  let(:page_definition) { nil }
  let(:subsection) { instance_double(Form::Subsection, id: "setup") }
  let(:form) { instance_double(Form, start_date: Time.zone.local(2023, 4, 1), start_year_2024_or_later?: false) }

  before do
    allow(subsection).to receive(:form).and_return(form)
  end

  it "has correct subsection" do
    expect(page.subsection).to eq(subsection)
  end

  it "has correct questions" do
    expect(page.questions.map(&:id)).to eq(%w[privacynotice])
  end

  it "has the correct id" do
    expect(page.id).to eq("privacy_notice")
  end

  it "has the correct description" do
    expect(page.description).to be_nil
  end

  context "when there are joint buyers" do
    subject(:page) { described_class.new(page_id, page_definition, subsection, joint_purchase: true) }

    context "when the form start year is before 2024" do
      let(:subsection) { instance_double(Form::Subsection, id: "household_characteristics") }

      it "has the expected copy_key" do
        expect(page.copy_key).to eq("sales.household_characteristics.privacynotice.joint_purchase")
      end
    end

    context "when the form start year is after 2024" do
      let(:form) { instance_double(Form, start_date: Time.zone.local(2024, 4, 1), start_year_2024_or_later?: true) }

      it "has the expected copy_key" do
        expect(page.copy_key).to eq("sales.setup.privacynotice.joint_purchase")
      end
    end

    it "has correct depends_on" do
      expect(page.depends_on).to eq([{ "joint_purchase?" => true }])
    end
  end

  context "when there is a single buyer" do
    subject(:page) { described_class.new(page_id, page_definition, subsection, joint_purchase: false) }

    context "when the form start year is before 2024" do
      let(:subsection) { instance_double(Form::Subsection, id: "household_characteristics") }

      it "has the expected copy_key" do
        expect(page.copy_key).to eq("sales.household_characteristics.privacynotice.not_joint_purchase")
      end
    end

    context "when the form start year is after 2024" do
      let(:form) { instance_double(Form, start_date: Time.zone.local(2024, 4, 1), start_year_2024_or_later?: true) }

      it "has the expected copy_key" do
        expect(page.copy_key).to eq("sales.setup.privacynotice.not_joint_purchase")
      end
    end

    it "has correct depends_on" do
      expect(page.depends_on).to eq([{ "not_joint_purchase?" => true }, { "jointpur" => nil }])
    end
  end
end
